import sys
import argparse
import logging

import zmq

from .config import Config
from .util import board_cfg_file
from .logger import setup_logger


def main() -> None:
    config = Config.get()

    context = None

    in_url: str = config.bridge.internal
    inside = None

    out_url: str = config.bridge.external
    outside = None

    logging.info('Starting bridge')

    context = zmq.Context()

    logging.debug('Internal: {}'.format(in_url))

    inside = context.socket(zmq.SUB)
    inside.setsockopt(zmq.RCVHWM, int(config.bridge.in_queue_size))
    inside.setsockopt(zmq.SUBSCRIBE, b'')
    try:
        inside.bind(in_url)
    except zmq.error.ZMQError as e:
        logging.error(e)
        inside.close()
        inside = None

    logging.debug('External: {}'.format(out_url))

    outside = context.socket(zmq.PUB)
    outside.setsockopt(zmq.SNDHWM, int(config.bridge.out_queue_size))
    try:
        outside.bind(out_url)
    except zmq.error.ZMQError as e:
        logging.error(e)
        outside.close()
        outside = None

    if inside and outside:
        logging.info('Running')

        try:
            zmq.proxy(inside, outside)
        except KeyboardInterrupt:
            pass

        logging.info('Bringing down bridge')

    if inside:
        inside.close()

    if outside:
        outside.close()

    if context:
        context.term()

    logging.info('Done')


def run_bridge(**kwargs):
    Config.init(board_cfg_file())
    setup_logger('bridge.txt')

    main()


if __name__ == '__main__':
    run_bridge()
