import sys
import os
import logging

from types import SimpleNamespace
from dataclasses import dataclass
from collections import namedtuple

from yaml import load, Loader


@dataclass
class Config():
    __instance = None

    filepath: str
    fullpath: str = None
    base_dir: str = None


    @classmethod
    def get(cls):
        if cls.__instance is None:
            raise RuntimeError('Config is not initialized yet')

        return cls.__instance


    @classmethod
    def init(cls, filepath):
        if cls.__instance:
            logging.warning('Config is initialized already')
        else:
            cls.__instance = Config(filepath=filepath)


    def __post_init__(self):
        relpath = '../..'

        self.base_dir = os.path.abspath(
            os.path.join(os.path.dirname(__file__),
            relpath))

        self.fullpath = os.path.abspath(os.path.join(
                self.base_dir,
                self.filepath))

        try:
            with open(self.fullpath, 'r') as f:
                data = load(f, Loader=Loader)
        except Exception as e:
            print(f'Failed to load config data: {e}')
            return

        def process(node):
            for k, v in node.items():
                if isinstance(v, dict):
                    node[k] = SimpleNamespace(**(process(v)))

            return node

        data = process(data)
        for k, v in data.items():
            setattr(self, k, v)
