import re


class FFmpegParser():
    def __init__(self):
        self.m_message = ''
        self.m_re_metadata = r"Input[\w\W]+?Stream.+?Video: (.+?)\n"
        self.m_re_chunk = r"Opening '(.+?)' for writing$"
        self.m_re_time = r"(frame=.+?time=.+?bitrate=.+?)(\r|\n)"

    def append(self, buf):
        self.m_message = self.m_message + buf.decode('utf-8')

    def process(self, meta=True, chunk=True, time=True):
        lastindex = -1

        file_path = None
        if chunk:
            match = re.search(self.m_re_chunk, self.m_message, re.MULTILINE)
            if match:
                file_path = match.group(1)
                (_, lastindex) = match.span()

        meta_msg = None
        if meta:
            match = re.search(self.m_re_metadata, self.m_message, re.MULTILINE)
            if match:
                # h264 (High), yuv420p(progressive), 1280x720 [SAR 1:1 DAR 16:9], 29.97 fps, 29.97 tbr, 1k tbn, 59.94 tbc (default)
                meta_msg = match.group(1)
                (_, index) = match.span()
                if lastindex < index:
                    lastindex = index

        info = None
        if time:
            match = re.search(self.m_re_time, self.m_message, re.MULTILINE)
            if match:
                info = match.group(1)

                (_, index) = match.span()
                if lastindex < index:
                    lastindex = index

        if lastindex != -1:
            self.m_message = self.m_message[lastindex:]

        return (file_path, meta_msg, info)
