import os
import logging
from logging.handlers import RotatingFileHandler

from .config import Config


def setup_logger(filename=None):
    kwargs = {
        'handlers': []
    }

    config = Config.get()
    if filename:
        logpath = os.path.join(
            config.base_dir,
            config.logs.location,
            filename)

        fullpath = os.path.abspath(logpath)
        kwargs['handlers'].append(
            RotatingFileHandler(
                fullpath,
                maxBytes=2*1024*1024,
                backupCount=5))

    levels = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'critical': logging.CRITICAL
    }

    kwargs['level'] = levels[config.logs.level.lower()]
    kwargs['format'] = "%(asctime)s %(filename)s %(levelname)s (%(funcName)s:%(lineno)d): %(message)s"
    kwargs['datefmt'] = "%H:%M:%S"
    kwargs['handlers'].append(logging.StreamHandler())

    logging.basicConfig(**kwargs)